<?php

    if (!defined('sugarEntry') || !sugarEntry) die('Not A Valid Entry Point');

    class frontend_cors_hook
    {
        function before_routing_method($event, $arguments)
        {
            try
            {
                if(!isset($arguments['request']) || !isset($arguments['api']) || !method_exists($arguments['request'], 'getHeader')) {
                    return;
                }

                $origin = $arguments['request']->getHeader('ORIGIN');
                if(empty($origin)) {
                    $origin = $arguments['request']->getHeader('Origin');
                    if(empty($origin)) {
                        $origin = $arguments['request']->getHeader('origin');
                    }
                }

                if(!empty($origin) && (stripos($origin, 'implicitfrontend.com') !== false || stripos($origin, 'crmcollaboration.com') !== false)) {
                    $GLOBALS['log']->info("Implicit FrontEnd: Origin found. Enabling CORS.");
                    
                    if(!method_exists($arguments['api'], 'getResponse')) {
                        $GLOBALS['log']->debug("Implicit FrontEnd: cannot get response. Skipping.");
                        return;
                    }
                    $response = $arguments['api']->getResponse();
                    if(!isset($response) || !method_exists($response, 'setHeader')) {
                        $GLOBALS['log']->debug("Implicit FrontEnd: empty response. Skipping.");
                        return;
                    }

                    if(method_exists($arguments['request'], 'getMethod')) {
                        $method = $arguments['request']->getMethod();
                    }

                    if(!empty($method) && strcasecmp($method, 'OPTIONS') == 0) {
                        $GLOBALS['log']->info("Implicit FrontEnd: OPTIONS request. Set to respond with HTTP Success.");
                        $response->setHeader('Access-Control-Allow-Origin', 'implicitfrontend');
                    }
                    else {
                        $response->setHeader('Access-Control-Allow-Origin', '*');
                    }
                    $GLOBALS['log']->info("Implicit FrontEnd: Setting CORS headers.");
                    $response->setHeader('Access-Control-Allow-Credentials', 'true');
                    $response->setHeader('Access-Control-Allow-Methods', 'GET, PUT, POST, DELETE, OPTIONS');
                    $response->setHeader('Access-Control-Allow-Headers', 'access-control-allow-origin, access-control-allow-headers, accept, x-api-applicationid, x-requested-with, content-type, authorization, oauth-token');
                }
            }
            catch(Exception $e) {
                $GLOBALS['log']->error("Implicit FrontEnd: Before Routing Error - " . $e->getMessage());
            }
        }

        function before_respond_method($event, $response)
        {
            try
            {
                if(isset($response) && $response->getHeader('Access-Control-Allow-Origin') === 'implicitfrontend') {
                    $GLOBALS['log']->info("Implicit FrontEnd: OPTIONS response. Setting HTTP Success.");
                    $response->setHeader('Access-Control-Allow-Origin', '*');
                    $response->setContent('');
                    $response->setStatus(200);
                }
            }
            catch(Exception $e) {
                $GLOBALS['log']->error("Implicit FrontEnd: Before Respond Error - " . $e->getMessage());
            }
        }
    }

?>